Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Options ¶
type Options struct {
// KubeConfigPath is the path of the kubeconfig file
KubeConfigPath string
// CatalogName is the name of the catalog to mirror
CatalogName string
// DestinationURI is the URI of the destination repo
DestinationURI string
// Push is true if images are to be pushed to the destinationURI
Push bool
// ConfigURI is the URI of the OCNE config file, only the applications in this file are mirrored
ConfigURI string
// Config is the OCNE configuration
Config *types.Config
// ClusterConfig is the cluster configuration
ClusterConfig *types.ClusterConfig
// DefaultRegistry is the registry to add to images without a domain. Stores the --source argument.
DefaultRegistry string
// Download is true if you want the images given by catalog mirror to be downloaded locally in a tar format.
Download bool
// Archive is the path to the .tgz file where images can be downloaded locally.
Archive string
}
Click to show internal directories.
Click to hide internal directories.